gradoptics.light\_sources.light\_source\_from\_distribution
=====================================================

.. automodule:: gradoptics.light_sources.light_source_from_distribution
   :members:
   :undoc-members:
   :show-inheritance:
